@@ -107,7 +107,7 @@ class Tebis():
 
 
     def getDataAsPD(self, names, start, end = None, rate=1):
-        if all(isinstance(elem, list) for elem in start):
+        if isinstance(start, list) and all(isinstance(elem, list) for elem in start):
             df = None
             for tuple in start:
                 if df is None:
